#include <Wire.h>
#include "Arduino.h"
#include "SoftwareSerial.h"
#include "EasyVR.h"

SoftwareSerial port(12,13);
EasyVR easyvr(port);
EasyVRBridge bridge;

//Groups and Commands
enum Groups
{
};
int8_t group, idx;
int8_t set = 0;
unsigned char state = 0;

void setup() {
   // bridge mode?
  if (bridge.check())
  {
    cli();
    bridge.loop(0, 1, 12, 13);
  }

  Wire.begin(0x07);                // join i2c bus with address #8
  Wire.onRequest(requestEvent); // register event
  Wire.onReceive(receiveEvent); // register event
  Serial.begin(9600);           // start serial for output
  port.begin(9600);
  
  if (!easyvr.detect())
  {
    Serial.println("EasyVR not detected!");
    for (;;);
  }

  easyvr.setPinOutput(EasyVR::IO1, LOW);
  Serial.println("EasyVR detected!");
  easyvr.setTimeout(5);
  //easyvr.setLanguage(EasyVR::ITALIAN);
  easyvr.setLanguage(EasyVR::ENGLISH);

  group = EasyVR::TRIGGER; //<-- start group (customize)
  //set = EasyVR::NUMBER_SET;
  //set = EasyVR::ACTION_SET;
  set = EasyVR::DIRECTION_SET;

}

void loop() {

  easyvr.setPinOutput(EasyVR::IO1, HIGH); // LED on (listening)

//  Serial.print("Say a command in Group ");
//  Serial.println(group);
//  easyvr.recognizeCommand(group);

    Serial.print("Say a word in Wordset ");
    Serial.println(set);
    easyvr.recognizeWord(set);

  do
  {
    // can do some processing while waiting for a spoken command
  }
  while (!easyvr.hasFinished());
  
  easyvr.setPinOutput(EasyVR::IO1, LOW); // LED off

  idx = easyvr.getWord();
  if (idx >= 0)
  {
    Serial.print("Word: ");
    Serial.print(easyvr.getWord());
    
    // built-in trigger (ROBOT)
    // group = GROUP_X; <-- jump to another group X
    switch(idx) {
       case 0: // left
         //digitalWrite(led, LOW); 
         state = 1;
         break;
       case 1: // right
         //digitalWrite(led, HIGH); 
         state = 2;
         break;
       case 3: // down
         state = 0;
         break;
       case 4: // forward
         state = 3;
         break;
       case 5: // backward
         state = 4;
         break;
       default:
         break; 
    }
    //return;
  }
  
/*  
  idx = easyvr.getCommand();
  if (idx >= 0)
  {
    // print debug message
    uint8_t train = 0;
    char name[32];
    Serial.print("Command: ");
    Serial.print(idx);
    if (easyvr.dumpCommand(group, idx, name, train))
    {
      Serial.print(" = ");
      Serial.println(name);
    }
    else
      Serial.println();
    easyvr.playSound(0, EasyVR::VOL_FULL);
    // perform some action
    action();
  }
  */
  else // errors or timeout
  {
    if (easyvr.isTimeout())
      Serial.println("Timed out, try again...");
    int16_t err = easyvr.getError();
    if (err >= 0)
    {
      Serial.print("Error ");
      Serial.println(err, HEX);
    }
  }  
}

// function that executes whenever data is requested by master
// this function is registered as an event, see setup()
void requestEvent() {
//  Serial.println("Data requested ");
  Wire.write(state); // respond with message of 1 byte as expected by master
//  Serial.println(state);
}

// function that executes whenever data is received from master
// this function is registered as an event, see setup()
void receiveEvent(int howMany) {
//  Serial.print("# of Bytes to recv: ");
//  int i = Wire.available();
//  Serial.print(i);
//  Serial.print(" - ");
//  i = 0;
//  while(Wire.available())
//  {
//    byte b = Wire.read();
//    Serial.print(b);
//    i ++;
//  }
//  Serial.println(" ");
//  Serial.println("Data received successfully");
}
